// Import External Dependencies
import React from 'react'
import PropTypes from 'prop-types'

// TODO: Use imitation and allow it to be passed as a prop
import { NavLink } from 'react-router-dom'

// Import Utilities
import Store from './store'



// Create and export the component
class Breadcrumbs extends React.Component {
    constructor(props) {
		super(props)
        this._unsubscribe = null
    }

    render() {
        let { className, wrapper: Wrapper, setCrumbs } = this.props,
         
            crumbs = Store.getState()

        /*crumbs = crumbs.sort((a, b) => {
          return a.pathname.length - b.pathname.length
        })*/

        if (setCrumbs) crumbs = setCrumbs(crumbs)

        return (
         
                <Wrapper className={ className }>
                    <div className={ `breadcrumb` }>
                        {
                            crumbs.map((crumb, i) => {
                                        if (i==crumbs.length-1)
                                            return (<span key={crumb.title} className="breadcrumb-item active" >{ crumb.title }</span>)
                                        return (<NavLink
                                            key={crumb.title}
                                            exact
                                            className="breadcrumb-item"
                                            activeClassName={ `breadcrumb-item active` }
                                            to={{
                                                pathname: crumb.pathname,
                                                search: crumb.search,
                                                state: crumb.state
                                            }}>
                                            { crumb.title }
                                        </NavLink>)
                            })
                        }
                    </div>
                    { this.props.children }
                </Wrapper>

              
    
        )
    }

    UNSAFE_componentWillMount() {
        this._unsubscribe = Store.subscribe(() => {
            this.forceUpdate()
        })
    }

    componentWillUnmount() {
        this._unsubscribe()
    }
}


Breadcrumbs.propTypes = {
    className: PropTypes.string,
    hidden: PropTypes.bool,
    separator: PropTypes.node,
    setCrumbs: PropTypes.func,
    wrapper: PropTypes.oneOfType([
        PropTypes.func,
        PropTypes.instanceOf(
            React.Component
        )
    ]),
    children: PropTypes.oneOfType([
        PropTypes.node,
        PropTypes.arrayOf(
            PropTypes.node
        )
    ])
}

Breadcrumbs.defaultProps = {
    className: '',
    hidden: false,
    separator: '>',
    setCrumbs: undefined,
    wrapper: props => ( // eslint-disable-line react/display-name
        <nav { ...props }>
            { props.children }
        </nav>
    )
}

export default Breadcrumbs